KEYWORDS_BASE = {
    "corrective": [
        "BROKE",
        "BUG",
        "CORRECT",
        "DEPRACE",
        "ERROR",
        "FAIL",
        "FIX",
        "ISSUE",
        "PATCH",
        "PROBLEM",
        "PROPER",
        "WRONG",
        "PREVENT",
        "AGAIN",
    ],
    "feature": [
        "ADD",
        "CREATE",
        "FEATURE",
        "INCLUDE",
        "INCREASE",
        "INITIAL",
        "INTRODUCE",
        "NEW",
        "REQUEST",
        "REQUIREMENT",
        "START",
    ],
    "management": [
        "CI",
        "COMMENT",
        "DOC",
        "FORMATTING",
        "LICENSE",
        "MANUAL",
        "MERGE",
        "MIGRAT",
        "ORGANIZ",
        "README",
        "RELEASE",
        "STRUCTURE",
        "TODO",
        "UPGRADE",
        "REVER",
        "TEMPORARY"
    ],
    "streamline": [
        "ADJUST",
        "ASSET",
        "BETTER",
        "CHANG",
        "CLEAN",
        "COVERAGE",
        "DELET",
        "ELIMINAT",
        "ENHANC",
        "IMPROV",
        "MISS",
        "MODIF",
        "OBSOLETE",
        "OPTIMIZ",
        "POLISH",
        "PRETT",
        "REARRANG",
        "REFACTOR",
        "REMOV",
        "RENAM",
        "REPLAC",
        "RESTRUCTUR",
        "SIMPLIFY",
        "TEST",
        "UNIT",
        "UPDATE",
        "VERBOSE",
    ]
}
